@@ -9,7 +9,7 @@ import time
 import pandas as pd
 
 
-def getAssetCandles(cfg: dict, asset: str, tsStart: int, tsEnd: int) -> pd.DataFrame:
+def getAssetCandles(cfg: dict, asset: str, tsStart: int, tsEnd: int, scale: float = 10000.0) -> pd.DataFrame:
     channel = grpc.insecure_channel(cfg['servaddr'])
     stub = trdb2py.tradingdb2_pb2_grpc.TradingDB2Stub(channel)
 
@@ -25,12 +25,15 @@ def getAssetCandles(cfg: dict, asset: str, tsStart: int, tsEnd: int) -> pd.DataF
         ),
     ))
 
-    fv = {'date': [], 'close': []}
+    fv = {'date': [], 'close': [], 'open': [], 'high': [], 'low': []}
     for curres in response:
         for candle in curres.candles.candles:
             fv['date'].append(datetime.fromtimestamp(
                 candle.ts).strftime('%Y-%m-%d'))
-            fv['close'].append(candle.close / 10000.0)
+            fv['open'].append(candle.open / scale)
+            fv['close'].append(candle.close / scale)
+            fv['high'].append(candle.high / scale)
+            fv['low'].append(candle.low / scale)
 
     return pd.DataFrame(fv)
 
